@@ -9,6 +9,9 @@ app: App = App()
 class Literals(ValueDictsBase):
     """ValueDicts for the dotnet module."""
 
+    _titles = {
+        "dotnet_ci_title_pipeline_kickoff": _(".NET CI pipeline kick off"),
+    }
     _info = {
         "dotnet_build_before": "Launching dotnet build inside {path}. Please wait..",
         "dotnet_ef_database_drop": "Dropping the database...",
@@ -30,7 +33,6 @@ class Literals(ValueDictsBase):
         "dotnet_ef_utils_appsettings_environment_matched": "Environment {environment} matched on: {filename}",
         "dotnet_ef_utils_appsettings_no_environment_matched": "No environment matched on: {filename}",
         "dotnet_ef_utils_getting_appsettings_files": "Getting appsettings files from: {path}",
-        "dotnet_project_version": "The project version is {version}",
         "dotnet_restore_before": "Launching dotnet restore inside {path}. Please wait..",
     }
     _errors = {
